@@ -20,11 +20,11 @@ Pod::Query - Query pod documents
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION       = '0.03';
+our $VERSION       = '0.04';
 our $DEBUG_TREE    = 0;
 our $DEBUG_FIND    = 0;
 our $DEBUG_INVERT  = 0;
@@ -242,7 +242,8 @@ sub _lol_to_tree ( $lol ) {
       return unless %$q;             # only if queue
       my $sub = $q->{sub};           # sub tags
       my $has = _has_head( $sub );
-      $q->{sub} = _lol_to_tree( $sub ) if $has;
+      $q->{sub} = _lol_to_tree( $sub )
+        if $has;    # TODO: rename "sub" to "inside" or "inner".
       push @main, $q;
       $q = {};
    };
@@ -348,31 +349,6 @@ sub _structure_over ( $text_list ) {
 }
 
 
-=pod
-   $pod->find(@sections)
-
-   Where each section can contain:
-   {
-      tag      => "TAG_NAME",     # Find all matching tags.
-      text     => "TEXT_NAME",    # Find all matching texts.
-      keep     => 1,              # Capture the text.
-      keep_all => 1,              # Capture entire section.
-      nth      => 0,              # Use only the nth match.
-   }
-
-   # Return contents of entire head section:
-   find (
-      {tag => "head", text => "a", keep_all => 1},
-   )
-
-   # Results:
-   # [
-   #    "  my \$app = a('/hel...",
-   #    {text => "Create a route with ...", wrap => 1},
-   #    "  \$ perl -Mojo -E ...",
-   # ]
-=cut
-
 =head2 find_title
 
 Extracts the title information.
@@ -380,7 +356,7 @@ Extracts the title information.
 =cut
 
 sub find_title ( $s ) {
-   $s->find(
+   scalar $s->find(
       {
          tag  => "head1",
          text => "NAME",
@@ -401,11 +377,10 @@ Extracts the complete method information.
 =cut
 
 sub find_method ( $s, $method ) {
-   my $FunctionCall = qr/ (?: \( [^()]* \) )? /x;
    $s->find(
       {
          tag       => qr/ ^ head \d $ /x,
-         text      => quotemeta( $method ) . $FunctionCall,
+         text      => quotemeta( $method ) . $s->_is_function_call,
          nth_group => 0,
          keep_all  => 1,
       },
@@ -420,11 +395,10 @@ Extracts the method summary.
 =cut
 
 sub find_method_summary ( $s, $method ) {
-   my $FunctionCall = qr/ (?: \( [^()]* \) )? /x;
-   $s->find(
+   scalar $s->find(
       {
          tag  => qr/ ^ head \d $ /x,
-         text => quotemeta( $method ) . $FunctionCall,
+         text => quotemeta( $method ) . $s->_is_function_call,
          nth  => 0,
       },
       {
@@ -435,10 +409,28 @@ sub find_method_summary ( $s, $method ) {
 }
 
 
+=head2 _is_function_call
+
+Regex for function call parenthesis.
+
+=cut
+
+sub _is_function_call {
+
+   # Optional "()".
+   qr/ (?:
+         \( [^()]* \)
+      )?
+   /x;
+}
+
+
 =head2 find_events
 
 Extracts a list of events with a description.
 
+Returns a list of key value pairs.
+
 =cut
 
 sub find_events ( $s ) {
@@ -462,7 +454,32 @@ sub find_events ( $s ) {
 
 =head2 find
 
-Generic extraction command
+Generic extraction command.
+
+context sensitive!
+
+   $pod->find(@sections)
+
+   Where each section can contain:
+   {
+      tag      => "TAG_NAME",     # Find all matching tags.
+      text     => "TEXT_NAME",    # Find all matching texts.
+      keep     => 1,              # Capture the text.
+      keep_all => 1,              # Capture entire section.
+      nth      => 0,              # Use only the nth match.
+   }
+
+   # Return contents of entire head section:
+   find (
+      {tag => "head", text => "a", keep_all => 1},
+   )
+
+   # Results:
+   # [
+   #    "  my \$app = a('/hel...",
+   #    {text => "Create a route with ...", wrap => 1},
+   #    "  \$ perl -Mojo -E ...",
+   # ]
 
 =cut
 
